import { _ as _export_sfc, c as createElementBlock, o as openBlock, a8 as createStaticVNode } from "./chunks/framework.B9AX-CPi.js";
const __pageData = JSON.parse('{"title":"ARM Debugging using Eclipse","description":"","frontmatter":{},"headers":[],"relativePath":"arm_debugging.md","filePath":"arm_debugging.md","lastUpdated":null}');
const _sfc_main = { name: "arm_debugging.md" };
const _hoisted_1 = /* @__PURE__ */ createStaticVNode('<h1 id="arm-debugging-using-eclipse" tabindex="-1">ARM Debugging using Eclipse <a class="header-anchor" href="#arm-debugging-using-eclipse" aria-label="Permalink to &quot;ARM Debugging using Eclipse&quot;">​</a></h1><p>This page describes how to setup debugging for ARM MCUs using an SWD adapter and open-source/free tools. In this guide we will install GNU MCU Eclipse IDE for C/C++ Developers and OpenOCD together with all the necessary dependencies.</p><p>This guide is catered towards advance users and assumes you can compile an ARM compatible keyboard on your machine using the MAKE flow.</p><h2 id="installing-the-software" tabindex="-1">Installing the software <a class="header-anchor" href="#installing-the-software" aria-label="Permalink to &quot;Installing the software&quot;">​</a></h2><p>The main objective here is to get the MCU Eclipse IDE correctly installed on our machine. The necessary instructions are derived from <a href="https://gnu-mcu-eclipse.github.io/install/" target="_blank" rel="noreferrer">this</a> install guide.</p><h3 id="the-xpack-manager" tabindex="-1">The xPack Manager <a class="header-anchor" href="#the-xpack-manager" aria-label="Permalink to &quot;The xPack Manager&quot;">​</a></h3><p>This tool is a software package manager and it is used to help us get the necessary dependencies.</p><p>XPM runs using Node.js so grab that from <a href="https://nodejs.org/en/" target="_blank" rel="noreferrer">here</a>. After installation, open a terminal and type <code>npm -v</code>. A reply with the version number means that the installation was successful.</p><p>XPM installation instructions can be found <a href="https://www.npmjs.com/package/xpm" target="_blank" rel="noreferrer">here</a> and are OS specific. Entering <code>xpm --version</code> to your terminal should return the software version.</p><h3 id="the-arm-toolchain" tabindex="-1">The ARM Toolchain <a class="header-anchor" href="#the-arm-toolchain" aria-label="Permalink to &quot;The ARM Toolchain&quot;">​</a></h3><p>Using XPM it is very easy to install the ARM toolchain. Enter the command <code>xpm install --global @xpack-dev-tools/arm-none-eabi-gcc</code>.</p><h3 id="windows-build-tools" tabindex="-1">Windows build tools <a class="header-anchor" href="#windows-build-tools" aria-label="Permalink to &quot;Windows build tools&quot;">​</a></h3><p>If you are using windows you need to install this!</p><p><code>xpm install --global @gnu-mcu-eclipse/windows-build-tools</code></p><h3 id="programmer-debugger-drivers" tabindex="-1">Programmer/Debugger Drivers <a class="header-anchor" href="#programmer-debugger-drivers" aria-label="Permalink to &quot;Programmer/Debugger Drivers&quot;">​</a></h3><p>Now it&#39;s time to install your programmer&#39;s drivers. This tutorial was made using an ST-Link v2 which you can get from almost anywhere. If you have an ST-Link the drivers can be found <a href="https://www.st.com/en/development-tools/stsw-link009.html" target="_blank" rel="noreferrer">here</a> otherwise consult the manufacturer of your tool.</p><h3 id="openocd" tabindex="-1">OpenOCD <a class="header-anchor" href="#openocd" aria-label="Permalink to &quot;OpenOCD&quot;">​</a></h3><p>This dependency allows SWD access from GDB and it is essential for debugging. Run <code>xpm install --global @xpack-dev-tools/openocd</code>.</p><h3 id="java" tabindex="-1">Java <a class="header-anchor" href="#java" aria-label="Permalink to &quot;Java&quot;">​</a></h3><p>Java is needed by Eclipse so please download it from <a href="https://www.oracle.com/technetwork/java/javase/downloads/index.html" target="_blank" rel="noreferrer">here</a>.</p><h3 id="gnu-mcu-eclipse-ide" tabindex="-1">GNU MCU Eclipse IDE <a class="header-anchor" href="#gnu-mcu-eclipse-ide" aria-label="Permalink to &quot;GNU MCU Eclipse IDE&quot;">​</a></h3><p>Now its finally time to install the IDE. Use the Release page <a href="https://github.com/gnu-mcu-eclipse/org.eclipse.epp.packages/releases/" target="_blank" rel="noreferrer">here</a> to get the latest version.</p><h2 id="configuring-eclipse" tabindex="-1">Configuring Eclipse <a class="header-anchor" href="#configuring-eclipse" aria-label="Permalink to &quot;Configuring Eclipse&quot;">​</a></h2><p>Open up the Eclipse IDE we just downloaded. To import our QMK directory select File -&gt; Import -&gt; C/C++ -&gt; Existing Code as Makefile Project. Select Next and use Browse to select your QMK folder. In the tool-chain list select ARM Cross GCC and select Finish.</p><p>Now you can see the QMK folder on the left hand side. Right click it and select Properties. On the left hand side, expand MCU and select ARM Toolchains Paths. Press xPack and OK. Repeat for OpenOCD Path and if you are on Windows for Build Tools Path. Select Apply and Close.</p><p>Now its time to install the necessary MCU packages. Go to Packs perspective by selecting Window -&gt; Perspective -&gt; Open Perspective -&gt; Other... -&gt; Packs. Now select the yellow refresh symbol next to the Packs tab. This will take a long time as it is requesting the MCU definitions from various places. If some of the links fail you can probably select Ignore.</p><p>When this finishes you must find the MCU which we will be building/debugging for. In this example I will be using the STM32F3 series MCUs. On the left, select STMicroelectronics -&gt; STM32F3 Series. On the middle window we can see the pack. Right click and select Install. Once that is done we can go back to the default perspective, Window -&gt; Perspective -&gt; Open Perspective -&gt; Other... -&gt; C/C++.</p><p>We need to let eclipse know the device we intent to build QMK on. Right click on the QMK folder -&gt; Properties -&gt; C/C++ Build -&gt; Settings. Select the Devices tab and under Devices select the appropriate variant of your MCU. For my example it is STM32F303CC</p><p>While we are here let&#39;s setup the build command as well. Select C/C++ Build and then the Behavior tab. On the Build command, replace <code>all</code> with your necessary make command. For example for a rev6 Planck with the default keymap this would be <code>planck/rev6:default</code>. Select Apply and Close.</p><h2 id="building" tabindex="-1">Building <a class="header-anchor" href="#building" aria-label="Permalink to &quot;Building&quot;">​</a></h2><p>If you have setup everything correctly pressing the hammer button should build the firmware for you and a .bin file should appear.</p><h2 id="debugging" tabindex="-1">Debugging <a class="header-anchor" href="#debugging" aria-label="Permalink to &quot;Debugging&quot;">​</a></h2><h3 id="connecting-the-debugger" tabindex="-1">Connecting the Debugger <a class="header-anchor" href="#connecting-the-debugger" aria-label="Permalink to &quot;Connecting the Debugger&quot;">​</a></h3><p>ARM MCUs use the Single Wire Debug (SWD) protocol which comprises of the clock (SWCLK) signal and the data (SWDIO) signal. Connecting this two wires and ground should be enough to allow full manipulation of the MCU. Here we assume that the keyboard will be powered though USB. The RESET signal is not necessary as we can manually assert it using the reset button. For a more advance setup, the SWO signal can be used which pipes printf and scanf asynchronously to the host but for our setup we will ignore it.</p><p>NOTE: Make sure the SWCLK and SWDIO pins are not used in the matrix of your keyboard. If they are you can temporarily switch them for some other pins.</p><h3 id="configuring-the-debugger" tabindex="-1">Configuring the Debugger <a class="header-anchor" href="#configuring-the-debugger" aria-label="Permalink to &quot;Configuring the Debugger&quot;">​</a></h3><p>Right click on your QMK folder, select Debug As -&gt; Debug Configurations... . Here double click on GDB OpenOCD Debugging. Select the Debugger tab and enter the configuration necessary for your MCU. This might take some fiddling and Googling to find out. The default script for the STM32F3 is called <code>stm32f3discovery.cfg</code>. To let OpenOCD know, in the Config options enter <code>-f board/stm32f3discovery.cfg</code>.</p><p>NOTE: In my case this configuration script requires editing to disable the reset assertion. The locations of the scripts can be found in the actual executable field usually under the path <code>openocd/version/.content/scripts/board</code>. Here I edited <code>reset_config srst_only</code> to <code>reset_config none</code>.</p><p>Select Apply and Close.</p><h3 id="running-the-debugger" tabindex="-1">Running the Debugger. <a class="header-anchor" href="#running-the-debugger" aria-label="Permalink to &quot;Running the Debugger.&quot;">​</a></h3><p>Reset your keyboard.</p><p>Press the bug icon and if all goes well you should soon find yourself in the Debug perspective. Here the program counter will pause at the beginning of the main function and wait for you to press Play. Most of the features of all debuggers work on Arm MCUs but for exact details Google is your friend!</p><p>Happy debugging!</p>', 43);
const _hoisted_44 = [
  _hoisted_1
];
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", null, _hoisted_44);
}
const arm_debugging = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
export {
  __pageData,
  arm_debugging as default
};
