import { _ as _export_sfc, c as createElementBlock, o as openBlock, a8 as createStaticVNode } from "./chunks/framework.B9AX-CPi.js";
const __pageData = JSON.parse('{"title":"Configuring QMK","description":"","frontmatter":{},"headers":[],"relativePath":"config_options.md","filePath":"config_options.md","lastUpdated":null}');
const _sfc_main = { name: "config_options.md" };
const _hoisted_1 = /* @__PURE__ */ createStaticVNode('<h1 id="configuring-qmk" tabindex="-1">Configuring QMK <a class="header-anchor" href="#configuring-qmk" aria-label="Permalink to &quot;Configuring QMK&quot;">​</a></h1><p>QMK is nearly infinitely configurable. Wherever possible we err on the side of allowing users to customize their keyboard, even at the expense of code size. That level of flexibility makes for a daunting configuration experience, however.</p><p>There are three main types of configuration files in QMK:</p><ul><li><code>config.h</code>, which contains various preprocessor directives (<code>#define</code>, <code>#ifdef</code>)</li><li><code>rules.mk</code>, which contains additional variables</li><li><code>info.json</code>, which is utilized for <a href="./data_driven_config">data-driven configuration</a></li></ul><p>This page will only discuss the first two types, <code>config.h</code> and <code>rules.mk</code>.</p><div class="tip custom-block"><p class="custom-block-title">TIP</p><p>While not all settings have data-driven equivalents yet, keyboard makers are encouraged to utilize the <code>info.json</code> file to set the metadata for their boards when possible. See the <a href="./reference_info_json"><code>info.json</code> Format</a> page for more details.</p></div><p>These files exist at various levels in QMK and all files of the same type are combined to build the final configuration. The levels, from lowest priority to highest priority, are:</p><ul><li>QMK Default</li><li>Keyboard</li><li>Folders (Up to 5 levels deep)</li><li>Keymap</li></ul><h2 id="qmk-default" tabindex="-1">QMK Default <a class="header-anchor" href="#qmk-default" aria-label="Permalink to &quot;QMK Default&quot;">​</a></h2><p>Every available setting in QMK has a default. If that setting is not set at the Keyboard, Folder, or Keymap level this is the setting that will be used.</p><h2 id="keyboard" tabindex="-1">Keyboard <a class="header-anchor" href="#keyboard" aria-label="Permalink to &quot;Keyboard&quot;">​</a></h2><p>This level contains config options that should apply to the whole keyboard. Some settings won&#39;t change in revisions, or most keymaps. Other settings are merely defaults for this keyboard and can be overridden by folders and/or keymaps.</p><h2 id="folders" tabindex="-1">Folders <a class="header-anchor" href="#folders" aria-label="Permalink to &quot;Folders&quot;">​</a></h2><p>Some keyboards have folders and sub-folders to allow for different hardware configurations. Most keyboards only go 1 folder deep, but QMK supports structures up to 5 folders deep. Each folder can have its own <code>config.h</code> and <code>rules.mk</code> files that are incorporated into the final configuration.</p><h2 id="keymap" tabindex="-1">Keymap <a class="header-anchor" href="#keymap" aria-label="Permalink to &quot;Keymap&quot;">​</a></h2><p>This level contains all of the options for that particular keymap. If you wish to override a previous declaration, you can use <code>#undef &lt;variable&gt;</code> to undefine it, where you can then redefine it without an error.</p><h1 id="the-config-h-file" tabindex="-1">The <code>config.h</code> File <a class="header-anchor" href="#the-config-h-file" aria-label="Permalink to &quot;The `config.h` File&quot;">​</a></h1><p>This is a C header file that is one of the first things included, and will persist over the whole project (if included). Lots of variables can be set here and accessed elsewhere. The <code>config.h</code> file shouldn&#39;t be including other <code>config.h</code> files.</p><h2 id="hardware-options" tabindex="-1">Hardware Options <a class="header-anchor" href="#hardware-options" aria-label="Permalink to &quot;Hardware Options&quot;">​</a></h2><ul><li><code>#define VENDOR_ID 0x1234</code><ul><li>defines your VID, and for most DIY projects, can be whatever you want</li></ul></li><li><code>#define PRODUCT_ID 0x5678</code><ul><li>defines your PID, and for most DIY projects, can be whatever you want</li></ul></li><li><code>#define DEVICE_VER 0x0100</code><ul><li>defines the device version (often used for revisions)</li></ul></li><li><code>#define MANUFACTURER &quot;Me&quot;</code><ul><li>generally who/whatever brand produced the board</li></ul></li><li><code>#define PRODUCT &quot;Board&quot;</code><ul><li>the name of the keyboard</li></ul></li><li><code>#define MATRIX_ROWS 5</code><ul><li>the number of rows in your keyboard&#39;s matrix</li></ul></li><li><code>#define MATRIX_COLS 15</code><ul><li>the number of columns in your keyboard&#39;s matrix</li></ul></li><li><code>#define MATRIX_ROW_PINS { D0, D5, B5, B6 }</code><ul><li>pins of the rows, from top to bottom</li><li>may be omitted by the keyboard designer if matrix reads are handled in an alternate manner. See <a href="./custom_quantum_functions#low-level-matrix-overrides">low-level matrix overrides</a> for more information.</li></ul></li><li><code>#define MATRIX_COL_PINS { F1, F0, B0, C7, F4, F5, F6, F7, D4, D6, B4, D7 }</code><ul><li>pins of the columns, from left to right</li><li>may be omitted by the keyboard designer if matrix reads are handled in an alternate manner. See <a href="./custom_quantum_functions#low-level-matrix-overrides">low-level matrix overrides</a> for more information.</li></ul></li><li><code>#define MATRIX_IO_DELAY 30</code><ul><li>the delay in microseconds when between changing matrix pin state and reading values</li></ul></li><li><code>#define MATRIX_HAS_GHOST</code><ul><li>define is matrix has ghost (unlikely)</li></ul></li><li><code>#define MATRIX_UNSELECT_DRIVE_HIGH</code><ul><li>On un-select of matrix pins, rather than setting pins to input-high, sets them to output-high.</li></ul></li><li><code>#define DIODE_DIRECTION COL2ROW</code><ul><li>COL2ROW or ROW2COL - how your matrix is configured. COL2ROW means the black mark on your diode is facing to the rows, and between the switch and the rows.</li></ul></li><li><code>#define DIRECT_PINS { { F1, F0, B0, C7 }, { F4, F5, F6, F7 } }</code><ul><li>pins mapped to rows and columns, from left to right. Defines a matrix where each switch is connected to a separate pin and ground.</li></ul></li><li><code>#define AUDIO_VOICES</code><ul><li>turns on the alternate audio voices (to cycle through)</li></ul></li><li><code>#define C4_AUDIO</code><ul><li>enables audio on pin C4</li><li>Deprecated. Use <code>#define AUDIO_PIN C4</code></li></ul></li><li><code>#define C5_AUDIO</code><ul><li>enables audio on pin C5</li><li>Deprecated. Use <code>#define AUDIO_PIN C5</code></li></ul></li><li><code>#define C6_AUDIO</code><ul><li>enables audio on pin C6</li><li>Deprecated. Use <code>#define AUDIO_PIN C6</code></li></ul></li><li><code>#define B5_AUDIO</code><ul><li>enables audio on pin B5 (duophony is enabled if one of B pins is enabled along with one of C pins)</li><li>Deprecated. Use <code>#define AUDIO_PIN B5</code>, or use <code>#define AUDIO_PIN_ALT B5</code> if a <code>C</code> pin is enabled with <code>AUDIO_PIN</code></li></ul></li><li><code>#define B6_AUDIO</code><ul><li>enables audio on pin B6 (duophony is enabled if one of B pins is enabled along with one of C pins)</li><li>Deprecated. Use <code>#define AUDIO_PIN B6</code>, or use <code>#define AUDIO_PIN_ALT B6</code> if a <code>C</code> pin is enabled with <code>AUDIO_PIN</code></li></ul></li><li><code>#define B7_AUDIO</code><ul><li>enables audio on pin B7 (duophony is enabled if one of B pins is enabled along with one of C pins)</li><li>Deprecated. Use <code>#define AUDIO_PIN B7</code>, or use <code>#define AUDIO_PIN_ALT B7</code> if a <code>C</code> pin is enabled with <code>AUDIO_PIN</code></li></ul></li><li><code>#define BACKLIGHT_PIN B7</code><ul><li>pin of the backlight</li></ul></li><li><code>#define BACKLIGHT_LEVELS 3</code><ul><li>number of levels your backlight will have (maximum 31 excluding off)</li></ul></li><li><code>#define BACKLIGHT_BREATHING</code><ul><li>enables backlight breathing</li></ul></li><li><code>#define BREATHING_PERIOD 6</code><ul><li>the length of one backlight &quot;breath&quot; in seconds</li></ul></li><li><code>#define DEBOUNCE 5</code><ul><li>the delay when reading the value of the pin (5 is default)</li></ul></li><li><code>#define LOCKING_SUPPORT_ENABLE</code><ul><li>mechanical locking support. Use KC_LCAP, KC_LNUM or KC_LSCR instead in keymap</li></ul></li><li><code>#define LOCKING_RESYNC_ENABLE</code><ul><li>tries to keep switch state consistent with keyboard LED state</li></ul></li><li><code>#define IS_COMMAND() (get_mods() == MOD_MASK_SHIFT)</code><ul><li>key combination that allows the use of magic commands (useful for debugging)</li></ul></li><li><code>#define USB_MAX_POWER_CONSUMPTION 500</code><ul><li>sets the maximum power (in mA) over USB for the device (default: 500)</li></ul></li><li><code>#define USB_POLLING_INTERVAL_MS 10</code><ul><li>sets the USB polling rate in milliseconds for the keyboard, mouse, and shared (NKRO/media keys) interfaces</li></ul></li><li><code>#define USB_SUSPEND_WAKEUP_DELAY 0</code><ul><li>sets the number of milliseconds to pause after sending a wakeup packet. Disabled by default, you might want to set this to 200 (or higher) if the keyboard does not wake up properly after suspending.</li></ul></li><li><code>#define F_SCL 100000L</code><ul><li>sets the I2C clock rate speed for keyboards using I2C. The default is <code>400000L</code>, except for keyboards using <code>split_common</code>, where the default is <code>100000L</code>.</li></ul></li></ul><h2 id="features-that-can-be-disabled" tabindex="-1">Features That Can Be Disabled <a class="header-anchor" href="#features-that-can-be-disabled" aria-label="Permalink to &quot;Features That Can Be Disabled&quot;">​</a></h2><p>If you define these options you will disable the associated feature, which can save on code size.</p><ul><li><code>#define NO_DEBUG</code><ul><li>disable debugging</li></ul></li><li><code>#define NO_PRINT</code><ul><li>disable printing/debugging using hid_listen</li></ul></li><li><code>#define NO_ACTION_LAYER</code><ul><li>disable layers</li></ul></li><li><code>#define NO_ACTION_TAPPING</code><ul><li>disable tap dance and other tapping features</li></ul></li><li><code>#define NO_ACTION_ONESHOT</code><ul><li>disable one-shot modifiers</li></ul></li></ul><h2 id="features-that-can-be-enabled" tabindex="-1">Features That Can Be Enabled <a class="header-anchor" href="#features-that-can-be-enabled" aria-label="Permalink to &quot;Features That Can Be Enabled&quot;">​</a></h2><p>If you define these options you will enable the associated feature, which may increase your code size.</p><ul><li><code>#define ENABLE_COMPILE_KEYCODE</code><ul><li>Enables the <code>QK_MAKE</code> keycode</li></ul></li><li><code>#define FORCE_NKRO</code><ul><li>NKRO by default requires to be turned on, this forces it on during keyboard startup regardless of EEPROM setting. NKRO can still be turned off but will be turned on again if the keyboard reboots.</li></ul></li><li><code>#define STRICT_LAYER_RELEASE</code><ul><li>force a key release to be evaluated using the current layer stack instead of remembering which layer it came from (used for advanced cases)</li></ul></li></ul><h2 id="behaviors-that-can-be-configured" tabindex="-1">Behaviors That Can Be Configured <a class="header-anchor" href="#behaviors-that-can-be-configured" aria-label="Permalink to &quot;Behaviors That Can Be Configured&quot;">​</a></h2><ul><li><code>#define TAPPING_TERM 200</code><ul><li>how long before a key press becomes a hold</li></ul></li><li><code>#define TAPPING_TERM_PER_KEY</code><ul><li>enables handling for per key <code>TAPPING_TERM</code> settings</li></ul></li><li><code>#define RETRO_TAPPING</code><ul><li>tap anyway, even after <code>TAPPING_TERM</code>, if there was no other key interruption between press and release</li><li>See <a href="./tap_hold#retro-tapping">Retro Tapping</a> for details</li></ul></li><li><code>#define RETRO_TAPPING_PER_KEY</code><ul><li>enables handling for per key <code>RETRO_TAPPING</code> settings</li></ul></li><li><code>#define TAPPING_TOGGLE 2</code><ul><li>how many taps before triggering the toggle</li></ul></li><li><code>#define PERMISSIVE_HOLD</code><ul><li>makes tap and hold keys trigger the hold if another key is pressed before releasing, even if it hasn&#39;t hit the <code>TAPPING_TERM</code></li><li>See <a href="./tap_hold#permissive-hold">Permissive Hold</a> for details</li></ul></li><li><code>#define PERMISSIVE_HOLD_PER_KEY</code><ul><li>enabled handling for per key <code>PERMISSIVE_HOLD</code> settings</li></ul></li><li><code>#define QUICK_TAP_TERM 100</code><ul><li>tap-then-hold timing to use a dual role key to repeat keycode</li><li>See <a href="./tap_hold#quick-tap-term">Quick Tap Term</a></li><li>Changes the timing of Tap Toggle functionality (<code>TT</code> or the One Shot Tap Toggle)</li><li>Defaults to <code>TAPPING_TERM</code> if not defined</li></ul></li><li><code>#define QUICK_TAP_TERM_PER_KEY</code><ul><li>enables handling for per key <code>QUICK_TAP_TERM</code> settings</li></ul></li><li><code>#define HOLD_ON_OTHER_KEY_PRESS</code><ul><li>selects the hold action of a dual-role key as soon as the tap of the dual-role key is interrupted by the press of another key.</li><li>See &quot;<a href="./tap_hold#hold-on-other-key-press">hold on other key press</a>&quot; for details</li></ul></li><li><code>#define HOLD_ON_OTHER_KEY_PRESS_PER_KEY</code><ul><li>enables handling for per key <code>HOLD_ON_OTHER_KEY_PRESS</code> settings</li></ul></li><li><code>#define LEADER_TIMEOUT 300</code><ul><li>how long before the leader key times out <ul><li>If you&#39;re having issues finishing the sequence before it times out, you may need to increase the timeout setting. Or you may want to enable the <code>LEADER_PER_KEY_TIMING</code> option, which resets the timeout after each key is tapped.</li></ul></li></ul></li><li><code>#define LEADER_PER_KEY_TIMING</code><ul><li>sets the timer for leader key chords to run on each key press rather than overall</li></ul></li><li><code>#define LEADER_KEY_STRICT_KEY_PROCESSING</code><ul><li>Disables keycode filtering for Mod-Tap and Layer-Tap keycodes. Eg, if you enable this, you would need to specify <code>MT(MOD_CTL, KC_A)</code> if you want to use <code>KC_A</code>.</li></ul></li><li><code>#define MOUSE_EXTENDED_REPORT</code><ul><li>Enables support for extended reports (-32767 to 32767, instead of -127 to 127), which may allow for smoother reporting, and prevent maxing out of the reports. Applies to both Pointing Device and Mousekeys.</li></ul></li><li><code>#define ONESHOT_TIMEOUT 300</code><ul><li>how long before oneshot times out</li></ul></li><li><code>#define ONESHOT_TAP_TOGGLE 2</code><ul><li>how many taps before oneshot toggle is triggered</li></ul></li><li><code>#define COMBO_TERM 200</code><ul><li>how long for the Combo keys to be detected. Defaults to <code>TAPPING_TERM</code> if not defined.</li></ul></li><li><code>#define COMBO_MUST_HOLD_MODS</code><ul><li>Flag for enabling extending timeout on Combos containing modifiers</li></ul></li><li><code>#define COMBO_MOD_TERM 200</code><ul><li>Allows for extending COMBO_TERM for mod keys while mid-combo.</li></ul></li><li><code>#define COMBO_MUST_HOLD_PER_COMBO</code><ul><li>Flag to enable per-combo COMBO_TERM extension and <code>get_combo_must_hold()</code> function</li></ul></li><li><code>#define COMBO_TERM_PER_COMBO</code><ul><li>Flag to enable per-combo COMBO_TERM extension and <code>get_combo_term()</code> function</li></ul></li><li><code>#define COMBO_STRICT_TIMER</code><ul><li>Only start the combo timer on the first key press instead of on all key presses.</li></ul></li><li><code>#define COMBO_NO_TIMER</code><ul><li>Disable the combo timer completely for relaxed combos.</li></ul></li><li><code>#define TAP_CODE_DELAY 100</code><ul><li>Sets the delay between <code>register_code</code> and <code>unregister_code</code>, if you&#39;re having issues with it registering properly (common on VUSB boards). The value is in milliseconds and defaults to <code>0</code>.</li></ul></li><li><code>#define TAP_HOLD_CAPS_DELAY 80</code><ul><li>Sets the delay for Tap Hold keys (<code>LT</code>, <code>MT</code>) when using <code>KC_CAPS_LOCK</code> keycode, as this has some special handling on MacOS. The value is in milliseconds, and defaults to 80 ms if not defined. For macOS, you may want to set this to 200 or higher.</li></ul></li><li><code>#define KEY_OVERRIDE_REPEAT_DELAY 500</code><ul><li>Sets the key repeat interval for <a href="./features/key_overrides">key overrides</a>.</li></ul></li><li><code>#define LEGACY_MAGIC_HANDLING</code><ul><li>Enables magic configuration handling for advanced keycodes (such as Mod Tap and Layer Tap)</li></ul></li></ul><h2 id="rgb-light-configuration" tabindex="-1">RGB Light Configuration <a class="header-anchor" href="#rgb-light-configuration" aria-label="Permalink to &quot;RGB Light Configuration&quot;">​</a></h2><ul><li><code>#define WS2812_DI_PIN D7</code><ul><li>pin the DI on the WS2812 is hooked-up to</li></ul></li><li><code>#define RGBLIGHT_LAYERS</code><ul><li>Lets you define <a href="./features/rgblight#lighting-layers">lighting layers</a> that can be toggled on or off. Great for showing the current keyboard layer or caps lock state.</li></ul></li><li><code>#define RGBLIGHT_MAX_LAYERS</code><ul><li>Defaults to 8. Can be expanded up to 32 if more <a href="./features/rgblight#lighting-layers">lighting layers</a> are needed.</li><li>Note: Increasing the maximum will increase the firmware size and slow sync on split keyboards.</li></ul></li><li><code>#define RGBLIGHT_LAYER_BLINK</code><ul><li>Adds ability to <a href="./features/rgblight#lighting-layer-blink">blink</a> a lighting layer for a specified number of milliseconds (e.g. to acknowledge an action).</li></ul></li><li><code>#define RGBLIGHT_LAYERS_OVERRIDE_RGB_OFF</code><ul><li>If defined, then <a href="./features/rgblight#overriding-rgb-lighting-onoff-status">lighting layers</a> will be shown even if RGB Light is off.</li></ul></li><li><code>#define RGBLIGHT_LED_COUNT 12</code><ul><li>number of LEDs</li></ul></li><li><code>#define RGBLIGHT_SPLIT</code><ul><li>Needed if both halves of the board have RGB LEDs wired directly to the RGB output pin on the controllers instead of passing the output of the left half to the input of the right half</li></ul></li><li><code>#define RGBLED_SPLIT { 6, 6 }</code><ul><li>number of LEDs connected that are directly wired to the RGB pin on each half of a split keyboard</li><li>First value indicates number of LEDs for left half, second value is for the right half</li><li>When RGBLED_SPLIT is defined, RGBLIGHT_SPLIT is implicitly defined.</li></ul></li><li><code>#define RGBLIGHT_HUE_STEP 12</code><ul><li>units to step when in/decreasing hue</li></ul></li><li><code>#define RGBLIGHT_SAT_STEP 25</code><ul><li>units to step when in/decreasing saturation</li></ul></li><li><code>#define RGBLIGHT_VAL_STEP 12</code><ul><li>units to step when in/decreasing value (brightness)</li></ul></li><li><code>#define WS2812_RGBW</code><ul><li>Enables RGBW LED support</li></ul></li></ul><h2 id="mouse-key-options" tabindex="-1">Mouse Key Options <a class="header-anchor" href="#mouse-key-options" aria-label="Permalink to &quot;Mouse Key Options&quot;">​</a></h2><ul><li><code>#define MOUSEKEY_INTERVAL 20</code></li><li><code>#define MOUSEKEY_DELAY 0</code></li><li><code>#define MOUSEKEY_TIME_TO_MAX 60</code></li><li><code>#define MOUSEKEY_MAX_SPEED 7</code></li><li><code>#define MOUSEKEY_WHEEL_DELAY 0</code></li></ul><h2 id="split-keyboard-options" tabindex="-1">Split Keyboard Options <a class="header-anchor" href="#split-keyboard-options" aria-label="Permalink to &quot;Split Keyboard Options&quot;">​</a></h2><p>Split Keyboard specific options, make sure you have &#39;SPLIT_KEYBOARD = yes&#39; in your rules.mk</p><ul><li><code>SPLIT_TRANSPORT = custom</code><ul><li>Allows replacing the standard split communication routines with a custom one. ARM based split keyboards must use this at present.</li></ul></li></ul><h3 id="setting-handedness" tabindex="-1">Setting Handedness <a class="header-anchor" href="#setting-handedness" aria-label="Permalink to &quot;Setting Handedness&quot;">​</a></h3><p>One thing to remember, the side that the USB port is plugged into is always the master half. The side not plugged into USB is the slave.</p><p>There are a few different ways to set handedness for split keyboards (listed in order of precedence):</p><ol><li>Set <code>SPLIT_HAND_PIN</code>: Reads a pin to determine handedness. If pin is high, it&#39;s the left side, if low, the half is determined to be the right side</li><li>Set <code>EE_HANDS</code> and flash <code>eeprom-lefthand.eep</code>/<code>eeprom-righthand.eep</code> to each half <ul><li>For boards with DFU bootloader you can use <code>:dfu-split-left</code>/<code>:dfu-split-right</code> to flash these EEPROM files</li><li>For boards with Caterina bootloader (like stock Pro Micros), use <code>:avrdude-split-left</code>/<code>:avrdude-split-right</code></li><li>For boards with ARM DFU bootloader (like Proton C), use <code>:dfu-util-split-left</code>/<code>:dfu-util-split-right</code></li></ul></li><li>Set <code>MASTER_RIGHT</code>: Half that is plugged into the USB port is determined to be the master and right half (inverse of the default)</li><li>Default: The side that is plugged into the USB port is the master half and is assumed to be the left half. The slave side is the right half</li></ol><h4 id="defines-for-handedness" tabindex="-1">Defines for handedness <a class="header-anchor" href="#defines-for-handedness" aria-label="Permalink to &quot;Defines for handedness&quot;">​</a></h4><ul><li><p><code>#define SPLIT_HAND_PIN B7</code></p><ul><li>For using high/low pin to determine handedness, low = right hand, high = left hand. Replace <code>B7</code> with the pin you are using. This is optional, and if you leave <code>SPLIT_HAND_PIN</code> undefined, then you can still use the EE_HANDS method or MASTER_LEFT / MASTER_RIGHT defines like the stock Let&#39;s Split uses.</li></ul></li><li><p><code>#define SPLIT_HAND_MATRIX_GRID &lt;out_pin&gt;,&lt;in_pin&gt;</code></p><ul><li>The handedness is determined by using the intersection of the keyswitches in the key matrix, which does not exist. Normally, when this intersection is shorted (level low), it is considered right. If you define <code>#define SPLIT_HAND_MATRIX_GRID_LOW_IS_LEFT</code>, it is determined to be left when the level is low.</li></ul></li><li><p><code>#define EE_HANDS</code> (only works if <code>SPLIT_HAND_PIN</code> and <code>SPLIT_HAND_MATRIX_GRID</code> are not defined)</p><ul><li>Reads the handedness value stored in the EEPROM after <code>eeprom-lefthand.eep</code>/<code>eeprom-righthand.eep</code> has been flashed to their respective halves.</li></ul></li><li><p><code>#define MASTER_RIGHT</code></p><ul><li>Master half is defined to be the right half.</li></ul></li></ul><h3 id="other-options" tabindex="-1">Other Options <a class="header-anchor" href="#other-options" aria-label="Permalink to &quot;Other Options&quot;">​</a></h3><ul><li><p><code>#define USE_I2C</code></p><ul><li>For using I2C instead of Serial (default is serial; serial transport is supported on ARM -- I2C is AVR-only)</li></ul></li><li><p><code>#define SOFT_SERIAL_PIN D0</code></p><ul><li>When using serial, define this. <code>D0</code> or <code>D1</code>,<code>D2</code>,<code>D3</code>,<code>E6</code>.</li></ul></li><li><p><code>#define MATRIX_ROW_PINS_RIGHT { &lt;row pins&gt; }</code></p></li><li><p><code>#define MATRIX_COL_PINS_RIGHT { &lt;col pins&gt; }</code></p><ul><li>If you want to specify a different pinout for the right half than the left half, you can define <code>MATRIX_ROW_PINS_RIGHT</code>/<code>MATRIX_COL_PINS_RIGHT</code>. Currently, the size of <code>MATRIX_ROW_PINS</code> must be the same as <code>MATRIX_ROW_PINS_RIGHT</code> and likewise for the definition of columns.</li><li>may be omitted by the keyboard designer if matrix reads are handled in an alternate manner. See <a href="./custom_quantum_functions#low-level-matrix-overrides">low-level matrix overrides</a> for more information.</li></ul></li><li><p><code>#define DIRECT_PINS_RIGHT { { F1, F0, B0, C7 }, { F4, F5, F6, F7 } }</code></p><ul><li>If you want to specify a different direct pinout for the right half than the left half, you can define <code>DIRECT_PINS_RIGHT</code>. Currently, the size of <code>DIRECT_PINS</code> must be the same as <code>DIRECT_PINS_RIGHT</code>.</li></ul></li><li><p><code>#define RGBLED_SPLIT { 6, 6 }</code></p><ul><li>See <a href="#rgb-light-configuration">RGB Light Configuration</a></li></ul></li><li><p><code>#define SELECT_SOFT_SERIAL_SPEED &lt;speed&gt;</code> (default speed is 1)</p><ul><li>Sets the protocol speed when using serial communication</li><li>Speeds: <ul><li>0: about 189kbps (Experimental only)</li><li>1: about 137kbps (default)</li><li>2: about 75kbps</li><li>3: about 39kbps</li><li>4: about 26kbps</li><li>5: about 20kbps</li></ul></li></ul></li><li><p><code>#define SPLIT_USB_DETECT</code></p><ul><li>Detect (with timeout) USB connection when delegating master/slave</li><li>Default behavior for ARM</li><li>Required for AVR Teensy (without hardware mods)</li></ul></li><li><p><code>#define SPLIT_USB_TIMEOUT 2000</code></p><ul><li>Maximum timeout when detecting master/slave when using <code>SPLIT_USB_DETECT</code></li></ul></li><li><p><code>#define SPLIT_USB_TIMEOUT_POLL 10</code></p><ul><li>Poll frequency when detecting master/slave when using <code>SPLIT_USB_DETECT</code></li></ul></li><li><p><code>#define SPLIT_WATCHDOG_ENABLE</code></p><ul><li>Reboot slave if no communication from master within timeout.</li><li>Helps resolve issue where both sides detect as slave using <code>SPLIT_USB_DETECT</code></li></ul></li><li><p><code>#define SPLIT_WATCHDOG_TIMEOUT 3000</code></p><ul><li>Maximum slave timeout when waiting for communication from master when using <code>SPLIT_WATCHDOG_ENABLE</code></li></ul></li><li><p><code>#define FORCED_SYNC_THROTTLE_MS 100</code></p><ul><li>Deadline for synchronizing data from master to slave when using the QMK-provided split transport.</li></ul></li><li><p><code>#define SPLIT_TRANSPORT_MIRROR</code></p><ul><li>Mirrors the master-side matrix on the slave when using the QMK-provided split transport.</li></ul></li><li><p><code>#define SPLIT_LAYER_STATE_ENABLE</code></p><ul><li>Ensures the current layer state is available on the slave when using the QMK-provided split transport.</li></ul></li><li><p><code>#define SPLIT_LED_STATE_ENABLE</code></p><ul><li>Ensures the current host indicator state (caps/num/scroll) is available on the slave when using the QMK-provided split transport.</li></ul></li><li><p><code>#define SPLIT_MODS_ENABLE</code></p><ul><li>Ensures the current modifier state (normal, weak, and oneshot) is available on the slave when using the QMK-provided split transport.</li></ul></li><li><p><code>#define SPLIT_WPM_ENABLE</code></p><ul><li>Ensures the current WPM is available on the slave when using the QMK-provided split transport.</li></ul></li><li><p><code>#define SPLIT_OLED_ENABLE</code></p><ul><li>Syncs the on/off state of the OLED between the halves.</li></ul></li><li><p><code>#define SPLIT_ST7565_ENABLE</code></p><ul><li>Syncs the on/off state of the ST7565 screen between the halves.</li></ul></li><li><p><code>#define SPLIT_TRANSACTION_IDS_KB .....</code></p></li><li><p><code>#define SPLIT_TRANSACTION_IDS_USER .....</code></p><ul><li>Allows for custom data sync with the slave when using the QMK-provided split transport. See <a href="./features/split_keyboard#custom-data-sync">custom data sync between sides</a> for more information.</li></ul></li></ul><h1 id="the-rules-mk-file" tabindex="-1">The <code>rules.mk</code> File <a class="header-anchor" href="#the-rules-mk-file" aria-label="Permalink to &quot;The `rules.mk` File&quot;">​</a></h1><p>This is a <a href="https://www.gnu.org/software/make/manual/make.html" target="_blank" rel="noreferrer">make</a> file that is included by the top-level <code>Makefile</code>. It is used to set some information about the MCU that we will be compiling for as well as enabling and disabling certain features.</p><h2 id="build-options" tabindex="-1">Build Options <a class="header-anchor" href="#build-options" aria-label="Permalink to &quot;Build Options&quot;">​</a></h2><ul><li><code>DEFAULT_FOLDER</code><ul><li>Used to specify a default folder when a keyboard has more than one sub-folder.</li></ul></li><li><code>FIRMWARE_FORMAT</code><ul><li>Defines which format (bin, hex) is copied to the root <code>qmk_firmware</code> folder after building.</li></ul></li><li><code>SRC</code><ul><li>Used to add files to the compilation/linking list.</li></ul></li><li><code>LIB_SRC</code><ul><li>Used to add files as a library to the compilation/linking list. The files specified by <code>LIB_SRC</code> is linked after the files specified by <code>SRC</code>. For example, if you specify:<div class="language- vp-adaptive-theme"><button title="Copy Code" class="copy"></button><span class="lang"></span><pre class="shiki shiki-themes github-light github-dark vp-code"><code><span class="line"><span>SRC += a.c</span></span>\n<span class="line"><span>LIB_SRC += lib_b.c</span></span>\n<span class="line"><span>SRC += c.c</span></span>\n<span class="line"><span>LIB_SRC += lib_d.c</span></span></code></pre></div>The link order is as follows.<div class="language- vp-adaptive-theme"><button title="Copy Code" class="copy"></button><span class="lang"></span><pre class="shiki shiki-themes github-light github-dark vp-code"><code><span class="line"><span> ...  a.o c.o  ...  lib_b.a lib_d.a  ...</span></span></code></pre></div></li></ul></li><li><code>LAYOUTS</code><ul><li>A list of <a href="./feature_layouts">layouts</a> this keyboard supports.</li></ul></li><li><code>LTO_ENABLE</code><ul><li>Enables Link Time Optimization (LTO) when compiling the keyboard. This makes the process take longer, but it can significantly reduce the compiled size (and since the firmware is small, the added time is not noticeable).</li></ul></li></ul><h2 id="avr-mcu-options" tabindex="-1">AVR MCU Options <a class="header-anchor" href="#avr-mcu-options" aria-label="Permalink to &quot;AVR MCU Options&quot;">​</a></h2><ul><li><code>MCU = atmega32u4</code></li><li><code>F_CPU = 16000000</code></li><li><code>ARCH = AVR8</code></li><li><code>F_USB = $(F_CPU)</code></li><li><code>OPT_DEFS += -DINTERRUPT_CONTROL_ENDPOINT</code></li><li><code>BOOTLOADER = atmel-dfu</code> with the following options: <ul><li><code>atmel-dfu</code></li><li><code>lufa-dfu</code></li><li><code>qmk-dfu</code></li><li><code>halfkay</code></li><li><code>caterina</code></li><li><code>bootloadhid</code></li><li><code>usbasploader</code></li></ul></li></ul><h2 id="feature-options" tabindex="-1">Feature Options <a class="header-anchor" href="#feature-options" aria-label="Permalink to &quot;Feature Options {#feature-options}&quot;">​</a></h2><p>Use these to enable or disable building certain features. The more you have enabled the bigger your firmware will be, and you run the risk of building a firmware too large for your MCU.</p><ul><li><code>MAGIC_ENABLE</code><ul><li>MAGIC actions (BOOTMAGIC without the boot)</li></ul></li><li><code>BOOTMAGIC_ENABLE</code><ul><li>Enable Bootmagic</li></ul></li><li><code>MOUSEKEY_ENABLE</code><ul><li>Mouse keys</li></ul></li><li><code>EXTRAKEY_ENABLE</code><ul><li>Audio control and System control</li></ul></li><li><code>CONSOLE_ENABLE</code><ul><li>Console for debug</li></ul></li><li><code>COMMAND_ENABLE</code><ul><li>Commands for debug and configuration</li></ul></li><li><code>COMBO_ENABLE</code><ul><li>Key combo feature</li></ul></li><li><code>NKRO_ENABLE</code><ul><li>USB N-Key Rollover - if this doesn&#39;t work, see here: <a href="https://github.com/tmk/tmk_keyboard/wiki/FAQ#nkro-doesnt-work" target="_blank" rel="noreferrer">https://github.com/tmk/tmk_keyboard/wiki/FAQ#nkro-doesnt-work</a></li></ul></li><li><code>AUDIO_ENABLE</code><ul><li>Enable the audio subsystem.</li></ul></li><li><code>KEY_OVERRIDE_ENABLE</code><ul><li>Enable the key override feature</li></ul></li><li><code>RGBLIGHT_ENABLE</code><ul><li>Enable keyboard underlight functionality</li></ul></li><li><code>LEADER_ENABLE</code><ul><li>Enable leader key chording</li></ul></li><li><code>MIDI_ENABLE</code><ul><li>MIDI controls</li></ul></li><li><code>UNICODE_ENABLE</code><ul><li>Unicode</li></ul></li><li><code>BLUETOOTH_ENABLE</code><ul><li>Current options are bluefruit_le, rn42</li></ul></li><li><code>SPLIT_KEYBOARD</code><ul><li>Enables split keyboard support (dual MCU like the let&#39;s split and bakingpy&#39;s boards) and includes all necessary files located at quantum/split_common</li></ul></li><li><code>CUSTOM_MATRIX</code><ul><li>Allows replacing the standard matrix scanning routine with a custom one.</li></ul></li><li><code>DEBOUNCE_TYPE</code><ul><li>Allows replacing the standard key debouncing routine with an alternative or custom one.</li></ul></li><li><code>USB_WAIT_FOR_ENUMERATION</code><ul><li>Forces the keyboard to wait for a USB connection to be established before it starts up</li></ul></li><li><code>NO_USB_STARTUP_CHECK</code><ul><li>Disables usb suspend check after keyboard startup. Usually the keyboard waits for the host to wake it up before any tasks are performed. This is useful for split keyboards as one half will not get a wakeup call but must send commands to the master.</li></ul></li><li><code>DEFERRED_EXEC_ENABLE</code><ul><li>Enables deferred executor support -- timed delays before callbacks are invoked. See <a href="./custom_quantum_functions#deferred-execution">deferred execution</a> for more information.</li></ul></li><li><code>DYNAMIC_TAPPING_TERM_ENABLE</code><ul><li>Allows to configure the global tapping term on the fly.</li></ul></li></ul><h2 id="usb-endpoint-limitations" tabindex="-1">USB Endpoint Limitations <a class="header-anchor" href="#usb-endpoint-limitations" aria-label="Permalink to &quot;USB Endpoint Limitations&quot;">​</a></h2><p>In order to provide services over USB, QMK has to use USB endpoints. These are a finite resource: each microcontroller has only a certain number. This limits what features can be enabled together. If the available endpoints are exceeded, a build error is thrown.</p><p>The following features can require separate endpoints:</p><ul><li><code>MOUSEKEY_ENABLE</code></li><li><code>EXTRAKEY_ENABLE</code></li><li><code>CONSOLE_ENABLE</code></li><li><code>NKRO_ENABLE</code></li><li><code>MIDI_ENABLE</code></li><li><code>RAW_ENABLE</code></li><li><code>VIRTSER_ENABLE</code></li></ul><p>In order to improve utilisation of the endpoints, the HID features can be combined to use a single endpoint. By default, <code>MOUSEKEY</code>, <code>EXTRAKEY</code>, and <code>NKRO</code> are combined into a single endpoint.</p><p>The base keyboard functionality can also be combined into the endpoint, by setting <code>KEYBOARD_SHARED_EP = yes</code>. This frees up one more endpoint, but it can prevent the keyboard working in some BIOSes, as they do not implement Boot Keyboard protocol switching.</p><p>Combining the mouse also breaks Boot Mouse compatibility. The mouse can be uncombined by setting <code>MOUSE_SHARED_EP = no</code> if this functionality is required.</p>', 59);
const _hoisted_60 = [
  _hoisted_1
];
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", null, _hoisted_60);
}
const config_options = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
export {
  __pageData,
  config_options as default
};
