import { _ as _export_sfc, c as createElementBlock, o as openBlock, a8 as createStaticVNode } from "./chunks/framework.B9AX-CPi.js";
const __pageData = JSON.parse('{"title":"Layers","description":"","frontmatter":{},"headers":[],"relativePath":"feature_layers.md","filePath":"feature_layers.md","lastUpdated":null}');
const _sfc_main = { name: "feature_layers.md" };
const _hoisted_1 = /* @__PURE__ */ createStaticVNode('<h1 id="layers" tabindex="-1">Layers <a class="header-anchor" href="#layers" aria-label="Permalink to &quot;Layers {#layers}&quot;">​</a></h1><p>One of the most powerful and well used features of QMK Firmware is the ability to use layers. For most people, this amounts to a function key that allows for different keys, much like what you would see on a laptop or tablet keyboard.</p><p>For a detailed explanation of how the layer stack works, checkout <a href="./keymap#keymap-and-layers">Keymap Overview</a>.</p><h2 id="switching-and-toggling-layers" tabindex="-1">Switching and Toggling Layers <a class="header-anchor" href="#switching-and-toggling-layers" aria-label="Permalink to &quot;Switching and Toggling Layers {#switching-and-toggling-layers}&quot;">​</a></h2><p>These functions allow you to activate layers in various ways. Note that layers are not generally independent layouts -- multiple layers can be activated at once, and it&#39;s typical for layers to use <code>KC_TRNS</code> to allow keypresses to pass through to lower layers. When using momentary layer switching with MO(), LM(), TT(), or LT(), make sure to leave the key on the above layers transparent or it may not work as intended.</p><ul><li><code>DF(layer)</code> - switches the default layer. The default layer is the always-active base layer that other layers stack on top of. See below for more about the default layer. This might be used to switch from QWERTY to Dvorak layout. Note that this is a temporary switch that only persists until the keyboard loses power.</li><li><code>PDF(layer)</code> - sets a persistent default layer. This switch, which will last through a power loss, might be used to switch from QWERTY to Dvorak layout and only switch again when you want to.</li><li><code>MO(layer)</code> - momentarily activates <em>layer</em>. As soon as you let go of the key, the layer is deactivated.</li><li><code>LM(layer, mod)</code> - Momentarily activates <em>layer</em> (like <code>MO</code>), but with modifier(s) <em>mod</em> active. Only supports layers 0-15. The modifiers this keycode accept are prefixed with <code>MOD_</code>, not <code>KC_</code>. These modifiers can be combined using bitwise OR, e.g. <code>LM(_RAISE, MOD_LCTL | MOD_LALT)</code>.</li><li><code>LT(layer, kc)</code> - momentarily activates <em>layer</em> when held, and sends <em>kc</em> when tapped. Only supports layers 0-15.</li><li><code>OSL(layer)</code> - momentarily activates <em>layer</em> until the next key is pressed. See <a href="./one_shot_keys">One Shot Keys</a> for details and additional functionality.</li><li><code>TG(layer)</code> - toggles <em>layer</em>, activating it if it&#39;s inactive and vice versa</li><li><code>TO(layer)</code> - activates <em>layer</em> and de-activates all other layers (except your default layer). This function is special, because instead of just adding/removing one layer to your active layer stack, it will completely replace your current active layers, uniquely allowing you to replace higher layers with a lower one. This is activated on keydown (as soon as the key is pressed).</li><li><code>TT(layer)</code> - Layer Tap-Toggle. If you hold the key down, <em>layer</em> is activated, and then is de-activated when you let go (like <code>MO</code>). If you repeatedly tap it, the layer will be toggled on or off (like <code>TG</code>). It needs 5 taps by default, but you can change this by defining <code>TAPPING_TOGGLE</code> -- for example, <code>#define TAPPING_TOGGLE 2</code> to toggle on just two taps.</li></ul><p>See also the <a href="./features/layer_lock">Layer Lock key</a>, which locks the highest active layer until pressed again.</p><h3 id="caveats" tabindex="-1">Caveats <a class="header-anchor" href="#caveats" aria-label="Permalink to &quot;Caveats {#caveats}&quot;">​</a></h3><p>Currently, the <code>layer</code> argument of <code>LT()</code> is limited to layers 0-15, and the <code>kc</code> argument to the <a href="./keycodes_basic">Basic Keycode set</a>, meaning you can&#39;t use keycodes like <code>LCTL()</code>, <code>KC_TILD</code>, or anything greater than <code>0xFF</code>. This is because QMK uses 16-bit keycodes, of which 4 bits are used for the function identifier and 4 bits for the layer, leaving only 8 bits for the keycode.</p><p>For a similar reason, the <code>layer</code> argument of <code>LM()</code> is also limited to layers 0-15 and the <code>mod</code> argument must fit within 5 bits. As a consequence, although left and right modifiers are supported by <code>LM()</code>, it is impossible to mix and match left and right modifiers. Specifying at least one right-hand modifier in a combination such as <code>MOD_RALT|MOD_LSFT</code> will convert <em>all</em> the listed modifiers to their right-hand counterpart. So, using the aforementionned mod-mask will actually send <kbd>Right Alt</kbd>+<kbd>Right Shift</kbd>. Make sure to use the <code>MOD_xxx</code> constants over alternative ways of specifying modifiers when defining your layer-mod key.</p><table><thead><tr><th style="text-align:center;"><code>LM(1,KC_LSFT)</code></th><th style="text-align:center;"><code>LM(1,MOD_MASK_SHIFT)</code></th><th style="text-align:center;"><code>LM(1,MOD_BIT(KC_LSFT))</code></th><th style="text-align:center;"><code>LM(1,MOD_LSFT)</code></th></tr></thead><tbody><tr><td style="text-align:center;">❌</td><td style="text-align:center;">❌</td><td style="text-align:center;">❌</td><td style="text-align:center;">✅</td></tr></tbody></table><p>Expanding this would be complicated, at best. Moving to a 32-bit keycode would solve a lot of this, but would double the amount of space that the keymap matrix uses. And it could potentially cause issues, too. If you need to apply modifiers to your tapped keycode, <a href="./features/tap_dance#example-5-using-tap-dance-for-advanced-mod-tap-and-layer-tap-keys">Tap Dance</a> can be used to accomplish this.</p><h2 id="working-with-layers" tabindex="-1">Working with Layers <a class="header-anchor" href="#working-with-layers" aria-label="Permalink to &quot;Working with Layers {#working-with-layers}&quot;">​</a></h2><p>Care must be taken when switching layers, it&#39;s possible to lock yourself into a layer with no way to deactivate that layer (without unplugging your keyboard.) We&#39;ve created some guidelines to help users avoid the most common problems.</p><h3 id="beginners" tabindex="-1">Beginners <a class="header-anchor" href="#beginners" aria-label="Permalink to &quot;Beginners {#beginners}&quot;">​</a></h3><p>If you are just getting started with QMK you will want to keep everything simple. Follow these guidelines when setting up your layers:</p><ul><li>Setup layer 0 as your default, &quot;base&quot; layer. This is your normal typing layer, and could be whatever layout you want (qwerty, dvorak, colemak, etc.). It&#39;s important to set this as the lowest layer since it will typically have most or all of the keyboard&#39;s keys defined, so would block other layers from having any effect if it were above them (i.e., had a higher layer number).</li><li>Arrange your layers in a &quot;tree&quot; layout, with layer 0 as the root. Do not try to enter the same layer from more than one other layer.</li><li>In a layer&#39;s keymap, only reference higher-numbered layers. Because layers are processed from the highest-numbered (topmost) active layer down, modifying the state of lower layers can be tricky and error-prone.</li></ul><h3 id="intermediate-users" tabindex="-1">Intermediate Users <a class="header-anchor" href="#intermediate-users" aria-label="Permalink to &quot;Intermediate Users {#intermediate-users}&quot;">​</a></h3><p>Sometimes you need more than one base layer. For example, if you want to switch between QWERTY and Dvorak, switch between layouts for different countries, or switch your layout for different videogames. Your base layers should always be the lowest numbered layers. When you have multiple base layers you should always treat them as mutually exclusive. When one base layer is on the others are off.</p><h3 id="advanced-users" tabindex="-1">Advanced Users <a class="header-anchor" href="#advanced-users" aria-label="Permalink to &quot;Advanced Users {#advanced-users}&quot;">​</a></h3><p>Once you have a good feel for how layers work and what you can do, you can get more creative. The rules listed in the beginner section will help you be successful by avoiding some of the tricker details but they can be constraining, especially for ultra-compact keyboard users. Understanding how layers work will allow you to use them in more advanced ways.</p><p>Layers stack on top of each other in numerical order. When determining what a keypress does, QMK scans the layers from the top down, stopping when it reaches the first active layer that is not set to <code>KC_TRNS</code>. As a result if you activate a layer that is numerically lower than your current layer, and your current layer (or another layer that is active and higher than your target layer) has something other than <code>KC_TRNS</code>, that is the key that will be sent, not the key on the layer you just activated. This is the cause of most people&#39;s &quot;why doesn&#39;t my layer get switched&quot; problem.</p><p>Sometimes, you might want to switch between layers in a macro or as part of a tap dance routine. <code>layer_on</code> activates a layer, and <code>layer_off</code> deactivates it. More layer-related functions can be found in <a href="https://github.com/qmk/qmk_firmware/blob/master/quantum/action_layer.h" target="_blank" rel="noreferrer">action_layer.h</a>.</p><h2 id="functions" tabindex="-1">Functions <a class="header-anchor" href="#functions" aria-label="Permalink to &quot;Functions {#functions}&quot;">​</a></h2><p>There are a number of functions (and variables) related to how you can use or manipulate the layers.</p><table><thead><tr><th>Function</th><th>Description</th></tr></thead><tbody><tr><td><code>layer_state_set(layer_mask)</code></td><td>Directly sets the layer state (avoid unless you know what you are doing).</td></tr><tr><td><code>layer_clear()</code></td><td>Clears all layers (turns them all off).</td></tr><tr><td><code>layer_move(layer)</code></td><td>Turns specified layer on, and all other layers off.</td></tr><tr><td><code>layer_on(layer)</code></td><td>Turns specified layer on, leaves all other layers in existing state.</td></tr><tr><td><code>layer_off(layer)</code></td><td>Turns specified layer off, leaves all other layers in existing state.</td></tr><tr><td><code>layer_invert(layer)</code></td><td>Inverts/toggles the state of the specified layer</td></tr><tr><td><code>layer_or(layer_mask)</code></td><td>Turns on layers based on matching bits between specifed layer and existing layer state.</td></tr><tr><td><code>layer_and(layer_mask)</code></td><td>Turns on layers based on matching enabled bits between specifed layer and existing layer state.</td></tr><tr><td><code>layer_xor(layer_mask)</code></td><td>Turns on layers based on non-matching bits between specifed layer and existing layer state.</td></tr><tr><td><code>layer_debug(layer_mask)</code></td><td>Prints out the current bit mask and highest active layer to debugger console.</td></tr><tr><td><code>default_layer_set(layer_mask)</code></td><td>Directly sets the default layer state (avoid unless you know what you are doing).</td></tr><tr><td><code>default_layer_or(layer_mask)</code></td><td>Turns on layers based on matching bits between specifed layer and existing default layer state.</td></tr><tr><td><code>default_layer_and(layer_mask)</code></td><td>Turns on layers based on matching enabled bits between specifed layer and existing default layer state.</td></tr><tr><td><code>default_layer_xor(layer_mask)</code></td><td>Turns on layers based on non-matching bits between specifed layer and existing default layer state.</td></tr><tr><td><code>default_layer_debug(layer_mask)</code></td><td>Prints out the current bit mask and highest active default layer to debugger console.</td></tr><tr><td><a href="./ref_functions#setting-the-persistent-default-layer"><code>set_single_default_layer(layer)</code></a></td><td>Sets the default layer, but does <em>not</em> write it to persistent memory (EEPROM).</td></tr><tr><td><a href="./ref_functions#setting-the-persistent-default-layer"><code>set_single_persistent_default_layer(layer)</code></a></td><td>Sets the default layer and writes it to persistent memory (EEPROM).</td></tr><tr><td><a href="./ref_functions#update_tri_layerx-y-z"><code>update_tri_layer(x, y, z)</code></a></td><td>Checks if layers <code>x</code> and <code>y</code> are both on, and sets <code>z</code> based on that (on if both on, otherwise off).</td></tr><tr><td><a href="./ref_functions#update_tri_layer_statestate-x-y-z"><code>update_tri_layer_state(state, x, y, z)</code></a></td><td>Does the same as <code>update_tri_layer(x, y, z)</code>, but from <code>layer_state_set_*</code> functions.</td></tr></tbody></table><p>In addition to the functions that you can call, there are a number of callback functions that get called every time the layer changes. This passes the layer state to the function, where it can be read or modified.</p><table><thead><tr><th>Callback</th><th>Description</th></tr></thead><tbody><tr><td><code>layer_state_set_kb(layer_state_t state)</code></td><td>Callback for layer functions, for keyboard.</td></tr><tr><td><code>layer_state_set_user(layer_state_t state)</code></td><td>Callback for layer functions, for users.</td></tr><tr><td><code>default_layer_state_set_kb(layer_state_t state)</code></td><td>Callback for default layer functions, for keyboard. Called on keyboard initialization.</td></tr><tr><td><code>default_layer_state_set_user(layer_state_t state)</code></td><td>Callback for default layer functions, for users. Called on keyboard initialization.</td></tr></tbody></table><div class="tip custom-block"><p class="custom-block-title">TIP</p><p>For additional details on how you can use these callbacks, check out the <a href="./custom_quantum_functions#layer-change-code">Layer Change Code</a> document.</p></div><p>It is also possible to check the state of a particular layer using the following functions and macros.</p><table><thead><tr><th>Function</th><th>Description</th><th>Aliases</th></tr></thead><tbody><tr><td><code>layer_state_is(layer)</code></td><td>Checks if the specified <code>layer</code> is enabled globally.</td><td><code>IS_LAYER_ON(layer)</code>, <code>IS_LAYER_OFF(layer)</code></td></tr><tr><td><code>layer_state_cmp(state, layer)</code></td><td>Checks <code>state</code> to see if the specified <code>layer</code> is enabled. Intended for use in layer callbacks.</td><td><code>IS_LAYER_ON_STATE(state, layer)</code>, <code>IS_LAYER_OFF_STATE(state, layer)</code></td></tr></tbody></table><h2 id="layer-change-code" tabindex="-1">Layer Change Code <a class="header-anchor" href="#layer-change-code" aria-label="Permalink to &quot;Layer Change Code {#layer-change-code}&quot;">​</a></h2><p>This runs code every time that the layers get changed. This can be useful for layer indication, or custom layer handling.</p><h3 id="example-layer-state-set-implementation" tabindex="-1">Example <code>layer_state_set_*</code> Implementation <a class="header-anchor" href="#example-layer-state-set-implementation" aria-label="Permalink to &quot;Example `layer_state_set_*` Implementation&quot;">​</a></h3><p>This example shows how to set the <a href="./features/rgblight">RGB Underglow</a> lights based on the layer, using the Planck as an example.</p><div class="language-c vp-adaptive-theme"><button title="Copy Code" class="copy"></button><span class="lang">c</span><pre class="shiki shiki-themes github-light github-dark vp-code"><code><span class="line"><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">layer_state_t</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> layer_state_set_user</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">layer_state_t</span><span style="--shiki-light:#E36209;--shiki-dark:#FFAB70;"> state</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">) {</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    switch</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">get_highest_layer</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(state)) {</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    case</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> _RAISE:</span></span>\n<span class="line"><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">        rgblight_setrgb</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">00</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">,  </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">00</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">FF</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">);</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">        break</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    case</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> _LOWER:</span></span>\n<span class="line"><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">        rgblight_setrgb</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">FF</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">,  </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">00</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">00</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">);</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">        break</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    case</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> _PLOVER:</span></span>\n<span class="line"><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">        rgblight_setrgb</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">00</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">,  </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">FF</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">00</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">);</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">        break</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    case</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> _ADJUST:</span></span>\n<span class="line"><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">        rgblight_setrgb</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">7A</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">,  </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">00</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">FF</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">);</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">        break</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    default</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">:</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;"> //  for any other layers, or the default layer</span></span>\n<span class="line"><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">        rgblight_setrgb</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">00</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">,  </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">FF</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">0x</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">FF</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">);</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">        break</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">    }</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">  return</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> state;</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">}</span></span></code></pre></div><h3 id="example-keycode-to-cycle-through-layers" tabindex="-1">Example: Keycode to cycle through layers <a class="header-anchor" href="#example-keycode-to-cycle-through-layers" aria-label="Permalink to &quot;Example: Keycode to cycle through layers&quot;">​</a></h3><p>This example shows how to implement a custom keycode to cycle through a range of layers.</p><div class="language-c vp-adaptive-theme"><button title="Copy Code" class="copy"></button><span class="lang">c</span><pre class="shiki shiki-themes github-light github-dark vp-code"><code><span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// Define the keycode, `QK_USER` avoids collisions with existing keycodes</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">enum</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> keycodes {</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">  KC_CYCLE_LAYERS </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> QK_USER,</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">};</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// 1st layer on the cycle</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">#define</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> LAYER_CYCLE_START</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> 0</span></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// Last layer on the cycle</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">#define</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> LAYER_CYCLE_END</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">   4</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// Add the behaviour of this new keycode</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">bool</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> process_record_user</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">uint16_t</span><span style="--shiki-light:#E36209;--shiki-dark:#FFAB70;"> keycode</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, </span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">keyrecord_t</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> *</span><span style="--shiki-light:#E36209;--shiki-dark:#FFAB70;">record</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">) {</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">  switch</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (keycode) {</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    case</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> KC_CYCLE_LAYERS:</span></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">      // Our logic will happen on presses, nothing is done on releases</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">      if</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">!</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">record</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">-&gt;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">event.pressed) { </span></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">        // We&#39;ve already handled the keycode (doing nothing), let QMK know so no further code is run unnecessarily</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">        return</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> false</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">      }</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">      uint8_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> current_layer </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> get_highest_layer</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(layer_state);</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">      // Check if we are within the range, if not quit</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">      if</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (current_layer </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">&gt;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> LAYER_CYCLE_END </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">||</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> current_layer </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">&lt;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> LAYER_CYCLE_START) {</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">        return</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> false</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">      }</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">      uint8_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> next_layer </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> current_layer </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">+</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> 1</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">      if</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (next_layer </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">&gt;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> LAYER_CYCLE_END) {</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">          next_layer </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> LAYER_CYCLE_START;</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">      }</span></span>\n<span class="line"><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">      layer_move</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(next_layer);</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">      return</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> false</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">    // Process other keycodes normally</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    default</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">:</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">      return</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> true</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">  }</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">}</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// Place `KC_CYCLE_LAYERS` as a keycode in your keymap</span></span></code></pre></div><p>Use the <code>IS_LAYER_ON_STATE(state, layer)</code> and <code>IS_LAYER_OFF_STATE(state, layer)</code> macros to check the status of a particular layer.</p><p>Outside of <code>layer_state_set_*</code> functions, you can use the <code>IS_LAYER_ON(layer)</code> and <code>IS_LAYER_OFF(layer)</code> macros to check global layer state.</p><h3 id="layer-state-set-function-documentation" tabindex="-1"><code>layer_state_set_*</code> Function Documentation <a class="header-anchor" href="#layer-state-set-function-documentation" aria-label="Permalink to &quot;`layer_state_set_*` Function Documentation&quot;">​</a></h3><ul><li>Keyboard/Revision: <code>layer_state_t layer_state_set_kb(layer_state_t state)</code></li><li>Keymap: <code>layer_state_t layer_state_set_user(layer_state_t state)</code></li></ul><p>The <code>state</code> is the bitmask of the active layers, as explained in the <a href="./keymap#keymap-layer-status">Keymap Overview</a></p>', 44);
const _hoisted_45 = [
  _hoisted_1
];
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", null, _hoisted_45);
}
const feature_layers = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
export {
  __pageData,
  feature_layers as default
};
