import { _ as _export_sfc, c as createElementBlock, o as openBlock, a8 as createStaticVNode } from "./chunks/framework.B9AX-CPi.js";
const __pageData = JSON.parse('{"title":"Key Overrides","description":"","frontmatter":{},"headers":[],"relativePath":"features/key_overrides.md","filePath":"features/key_overrides.md","lastUpdated":null}');
const _sfc_main = { name: "features/key_overrides.md" };
const _hoisted_1 = /* @__PURE__ */ createStaticVNode('<h1 id="key-overrides" tabindex="-1">Key Overrides <a class="header-anchor" href="#key-overrides" aria-label="Permalink to &quot;Key Overrides {#key-overrides}&quot;">​</a></h1><p>Key overrides allow you to override modifier-key combinations to send a different modifier-key combination or perform completely custom actions. Don&#39;t want <code>shift</code> + <code>1</code> to type <code>!</code> on your computer? Use a key override to make your keyboard type something different when you press <code>shift</code> + <code>1</code>. The general behavior is like this: If <code>modifiers w</code> + <code>key x</code> are pressed, replace these keys with <code>modifiers y</code> + <code>key z</code> in the keyboard report.</p><p>You can use key overrides in a similar way to momentary layer/fn keys to activate custom keycodes/shortcuts, with a number of benefits: You completely keep the original use of the modifier keys, while being able to save space by removing fn keys from your keyboard. You can also easily configure <em>combinations of modifiers</em> to trigger different actions than individual modifiers, and much more. The possibilities are quite vast and this documentation contains a few examples for inspiration throughout.</p><h5 id="a-few-more-examples-to-get-started-you-could-use-key-overrides-to" tabindex="-1">A few more examples to get started: You could use key overrides to... <a class="header-anchor" href="#a-few-more-examples-to-get-started-you-could-use-key-overrides-to" aria-label="Permalink to &quot;A few more examples to get started: You could use key overrides to...&quot;">​</a></h5><ul><li>Send <code>brightness up/down</code> when pressing <code>ctrl</code> + <code>volume up/down</code>.</li><li>Send <code>delete</code> when pressing <code>shift</code> + <code>backspace</code>.</li><li>Create custom shortcuts or change existing ones: E.g. Send <code>ctrl</code>+<code>shift</code>+<code>z</code> when <code>ctrl</code>+<code>y</code> is pressed.</li><li>Run custom code when <code>ctrl</code> + <code>alt</code> + <code>esc</code> is pressed.</li></ul><h2 id="setup" tabindex="-1">Setup <a class="header-anchor" href="#setup" aria-label="Permalink to &quot;Setup {#setup}&quot;">​</a></h2><p>To enable this feature, you need to add <code>KEY_OVERRIDE_ENABLE = yes</code> to your <code>rules.mk</code>.</p><p>Then, in your <code>keymap.c</code> file, you&#39;ll need to define the array <code>key_overrides</code>, which defines all key overrides to be used. Each override is a value of type <code>key_override_t</code>. The array <code>key_overrides</code>contains pointers to <code>key_override_t</code> values (<code>const key_override_t **</code>).</p><h2 id="creating-key-overrides" tabindex="-1">Creating Key Overrides <a class="header-anchor" href="#creating-key-overrides" aria-label="Permalink to &quot;Creating Key Overrides {#creating-key-overrides}&quot;">​</a></h2><p>The <code>key_override_t</code> struct has many options that allow you to precisely tune your overrides. The full reference is shown below. Instead of manually creating a <code>key_override_t</code> value, it is recommended to use these dedicated initializers:</p><h4 id="ko-make-basic-modifiers-key-replacement" tabindex="-1"><code>ko_make_basic(modifiers, key, replacement)</code> <a class="header-anchor" href="#ko-make-basic-modifiers-key-replacement" aria-label="Permalink to &quot;`ko_make_basic(modifiers, key, replacement)`&quot;">​</a></h4><p>Returns a <code>key_override_t</code>, which sends <code>replacement</code> (can be a key-modifier combination), when <code>key</code> and <code>modifiers</code> are all pressed down. This override still activates if any additional modifiers not specified in <code>modifiers</code> are also pressed down. See <code>ko_make_with_layers_and_negmods</code> to customize this behavior.</p><h4 id="ko-make-with-layers-modifiers-key-replacement-layers" tabindex="-1"><code>ko_make_with_layers(modifiers, key, replacement, layers)</code> <a class="header-anchor" href="#ko-make-with-layers-modifiers-key-replacement-layers" aria-label="Permalink to &quot;`ko_make_with_layers(modifiers, key, replacement, layers)`&quot;">​</a></h4><p>Additionally takes a bitmask <code>layers</code> that defines on which layers the override is used.</p><h4 id="ko-make-with-layers-and-negmods-modifiers-key-replacement-layers-negative-mods" tabindex="-1"><code>ko_make_with_layers_and_negmods(modifiers, key, replacement, layers, negative_mods)</code> <a class="header-anchor" href="#ko-make-with-layers-and-negmods-modifiers-key-replacement-layers-negative-mods" aria-label="Permalink to &quot;`ko_make_with_layers_and_negmods(modifiers, key, replacement, layers, negative_mods)`&quot;">​</a></h4><p>Additionally takes a bitmask <code>negative_mods</code> that defines which modifiers may not be pressed for this override to activate.</p><h4 id="ko-make-with-layers-negmods-and-options-modifiers-key-replacement-layers-negative-mods-options" tabindex="-1"><code>ko_make_with_layers_negmods_and_options(modifiers, key, replacement, layers, negative_mods, options)</code> <a class="header-anchor" href="#ko-make-with-layers-negmods-and-options-modifiers-key-replacement-layers-negative-mods-options" aria-label="Permalink to &quot;`ko_make_with_layers_negmods_and_options(modifiers, key, replacement, layers, negative_mods, options)`&quot;">​</a></h4><p>Additionally takes a bitmask <code>options</code> that specifies additional options. See <code>ko_option_t</code> for available options.</p><p>For more customization possibilities, you may directly create a <code>key_override_t</code>, which allows you to customize even more behavior. Read further below for details and examples.</p><h2 id="simple-example" tabindex="-1">Simple Example <a class="header-anchor" href="#simple-example" aria-label="Permalink to &quot;Simple Example {#simple-example}&quot;">​</a></h2><p>This shows how the mentioned example of sending <code>delete</code> when <code>shift</code> + <code>backspace</code> are pressed is realized:</p><div class="language-c vp-adaptive-theme"><button title="Copy Code" class="copy"></button><span class="lang">c</span><pre class="shiki shiki-themes github-light github-dark vp-code"><code><span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> delete_key_override </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> ko_make_basic</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(MOD_MASK_SHIFT, KC_BSPC, KC_DEL);</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// This globally defines all key overrides to be used</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> *</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">key_overrides</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">[]</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> =</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> {</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">	&amp;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">delete_key_override</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">};</span></span></code></pre></div><h2 id="intermediate-difficulty-examples" tabindex="-1">Intermediate Difficulty Examples <a class="header-anchor" href="#intermediate-difficulty-examples" aria-label="Permalink to &quot;Intermediate Difficulty Examples {#intermediate-difficulty-examples}&quot;">​</a></h2><h3 id="media-controls-amp-screen-brightness" tabindex="-1">Media Controls &amp; Screen Brightness <a class="header-anchor" href="#media-controls-amp-screen-brightness" aria-label="Permalink to &quot;Media Controls &amp; Screen Brightness {#media-controls-amp-screen-brightness}&quot;">​</a></h3><p>In this example a single key is configured to control media, volume and screen brightness by using key overrides.</p><ul><li>The key is set to send <code>play/pause</code> in the keymap.</li></ul><p>The following key overrides will be configured:</p><ul><li><code>Ctrl</code> + <code>play/pause</code> will send <code>next track</code>.</li><li><code>Ctrl</code> + <code>Shift</code> + <code>play/pause</code> will send <code>previous track</code>.</li><li><code>Alt</code> + <code>play/pause</code> will send <code>volume up</code>.</li><li><code>Alt</code> + <code>Shift</code> + <code>play/pause</code> will send <code>volume down</code>.</li><li><code>Ctrl</code> + <code>Alt</code> + <code>play/pause</code> will send <code>brightness up</code>.</li><li><code>Ctrl</code> + <code>Alt</code> + <code>Shift</code> + <code>play/pause</code> will send <code>brightness down</code>.</li></ul><div class="language-c vp-adaptive-theme"><button title="Copy Code" class="copy"></button><span class="lang">c</span><pre class="shiki shiki-themes github-light github-dark vp-code"><code><span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> next_track_override </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> </span></span>\n<span class="line"><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">	ko_make_with_layers_negmods_and_options</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">   		MOD_MASK_CTRL,</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">       // Trigger modifiers: ctrl</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">    	KC_MPLY,</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">             // Trigger key: play/pause</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">    	KC_MNXT,</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">             // Replacement key</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    	~</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">0</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">,</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">                  // Activate on all layers</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">    	MOD_MASK_SA,</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">         // Do not activate when shift or alt are pressed</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">    	ko_option_no_reregister_trigger);</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;"> // Specifies that the play key is not registered again after lifting ctrl</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">    </span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> prev_track_override </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> ko_make_with_layers_negmods_and_options</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(MOD_MASK_CS, KC_MPLY,</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">											KC_MPRV, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">~</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">0</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, MOD_MASK_ALT, ko_option_no_reregister_trigger);</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> vol_up_override </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> ko_make_with_layers_negmods_and_options</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(MOD_MASK_ALT, KC_MPLY,</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">											KC_VOLU, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">~</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">0</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, MOD_MASK_CS, ko_option_no_reregister_trigger);</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> vol_down_override </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> ko_make_with_layers_negmods_and_options</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(MOD_MASK_SA, KC_MPLY,</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">											KC_VOLD, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">~</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">0</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, MOD_MASK_CTRL, ko_option_no_reregister_trigger);</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> brightness_up_override </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> ko_make_with_layers_negmods_and_options</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(MOD_MASK_CA, KC_MPLY,</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">											KC_BRIU, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">~</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">0</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, MOD_MASK_SHIFT, ko_option_no_reregister_trigger);</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> brightness_down_override </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> ko_make_basic</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(MOD_MASK_CSA, KC_MPLY, KC_BRID);</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// This globally defines all key overrides to be used</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> *</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">key_overrides</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">[]</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> =</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> {</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">	&amp;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">next_track_override,</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">	&amp;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">prev_track_override,</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">	&amp;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">vol_up_override,</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">	&amp;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">vol_down_override,</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">	&amp;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">brightness_up_override,</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">	&amp;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">brightness_down_override</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">};</span></span></code></pre></div><h3 id="flexible-macos-friendly-grave-escape" tabindex="-1">Flexible macOS-friendly Grave Escape <a class="header-anchor" href="#flexible-macos-friendly-grave-escape" aria-label="Permalink to &quot;Flexible macOS-friendly Grave Escape {#flexible-macos-friendly-grave-escape}&quot;">​</a></h3><p>The <a href="./grave_esc">Grave Escape feature</a> is limited in its configurability and has <a href="./grave_esc#caveats">bugs when used on macOS</a>. Key overrides can be used to achieve a similar functionality as Grave Escape, but with more customization and without bugs on macOS.</p><div class="language-c vp-adaptive-theme"><button title="Copy Code" class="copy"></button><span class="lang">c</span><pre class="shiki shiki-themes github-light github-dark vp-code"><code><span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// Shift + esc = ~</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> tilde_esc_override </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> ko_make_basic</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(MOD_MASK_SHIFT, KC_ESC, </span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">S</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_GRV));</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// GUI + esc = `</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> grave_esc_override </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> ko_make_basic</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(MOD_MASK_GUI, KC_ESC, KC_GRV);</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> *</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">key_overrides</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">[]</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> =</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> {</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">	&amp;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">tilde_esc_override,</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">	&amp;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">grave_esc_override</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">};</span></span></code></pre></div><p>In addition to not encountering unexpected bugs on macOS, you can also change the behavior as you wish. Instead setting <code>GUI</code> + <code>ESC</code> = <code>`</code> you may change it to an arbitrary other modifier, for example <code>Ctrl</code> + <code>ESC</code> = <code>`</code>.</p><h2 id="advanced-examples" tabindex="-1">Advanced Examples <a class="header-anchor" href="#advanced-examples" aria-label="Permalink to &quot;Advanced Examples {#advanced-examples}&quot;">​</a></h2><h3 id="modifiers-as-layer-keys" tabindex="-1">Modifiers as Layer Keys <a class="header-anchor" href="#modifiers-as-layer-keys" aria-label="Permalink to &quot;Modifiers as Layer Keys {#modifiers-as-layer-keys}&quot;">​</a></h3><p>Do you really need a dedicated key to toggle your fn layer? With key overrides, perhaps not. This example shows how you can configure to use <code>rGUI</code> + <code>rAlt</code> (right GUI and right alt) to access a momentary layer like an fn layer. With this you completely eliminate the need to use a dedicated layer key. Of course the choice of modifier keys can be changed as needed, <code>rGUI</code> + <code>rAlt</code> is just an example here.</p><div class="language-c vp-adaptive-theme"><button title="Copy Code" class="copy"></button><span class="lang">c</span><pre class="shiki shiki-themes github-light github-dark vp-code"><code><span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// This is called when the override activates and deactivates. Enable the fn layer on activation and disable on deactivation</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">bool</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> momentary_layer</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">bool</span><span style="--shiki-light:#E36209;--shiki-dark:#FFAB70;"> key_down</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">void</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> *</span><span style="--shiki-light:#E36209;--shiki-dark:#FFAB70;">layer</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">) {</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    if</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (key_down) {</span></span>\n<span class="line"><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">        layer_on</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">((</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">uint8_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">)(</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">uintptr_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">)layer);</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">    } </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">else</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> {</span></span>\n<span class="line"><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">        layer_off</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">((</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">uint8_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">)(</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">uintptr_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">)layer);</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">    }</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">    return</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> false</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">;</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">}</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">const</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> key_override_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> fn_override </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> {.trigger_mods          </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_RGUI) </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">|</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_RCTL),</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">                       //</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">                                   .layers                 </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> ~</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;">1</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> &lt;&lt;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> LAYER_FN),</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">                                          //</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">                                   .suppressed_mods        </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_RGUI) </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">|</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_RCTL),</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">                       //</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">                                   .options                </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> ko_option_no_unregister_on_other_key_down,</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">                 //</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">                                   .negative_mod_mask      </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">uint8_t</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">) </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">~</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_RGUI) </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">|</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_RCTL)),</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">          //</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">                                   .custom_action          </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> momentary_layer,</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">                                           //</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">                                   .context                </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> (</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">void</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;"> *</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">)LAYER_FN,</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">                                          //</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">                                   .trigger                </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> KC_NO,</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">                                                     //</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">                                   .replacement            </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> KC_NO,</span><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">                                                     //</span></span>\n<span class="line"><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">                                   .enabled                </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">=</span><span style="--shiki-light:#005CC5;--shiki-dark:#79B8FF;"> NULL</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">};</span></span></code></pre></div><h2 id="keycodes" tabindex="-1">Keycodes <a class="header-anchor" href="#keycodes" aria-label="Permalink to &quot;Keycodes {#keycodes}&quot;">​</a></h2><table><thead><tr><th>Keycode</th><th>Aliases</th><th>Description</th></tr></thead><tbody><tr><td><code>QK_KEY_OVERRIDE_TOGGLE</code></td><td><code>KO_TOGG</code></td><td>Toggle key overrides</td></tr><tr><td><code>QK_KEY_OVERRIDE_ON</code></td><td><code>KO_ON</code></td><td>Turn on key overrides</td></tr><tr><td><code>QK_KEY_OVERRIDE_OFF</code></td><td><code>KO_OFF</code></td><td>Turn off key overrides</td></tr></tbody></table><h2 id="reference-for-key_override_t" tabindex="-1">Reference for <code>key_override_t</code> <a class="header-anchor" href="#reference-for-key_override_t" aria-label="Permalink to &quot;Reference for `key_override_t` {#reference-for-key_override_t}&quot;">​</a></h2><p>Advanced users may need more customization than what is offered by the simple <code>ko_make</code> initializers. For this, directly create a <code>key_override_t</code> value and set all members. Below is a reference for all members of <code>key_override_t</code>.</p><table><thead><tr><th>Member</th><th>Description</th></tr></thead><tbody><tr><td><code>uint16_t trigger</code></td><td>The non-modifier keycode that triggers the override. This keycode, and the necessary modifiers (<code>trigger_mods</code>) must be pressed to activate this override. Set this to the keycode of the key that should activate the override. Set to <code>KC_NO</code> to require only the necessary modifiers to be pressed and no non-modifier.</td></tr><tr><td><code>uint8_t trigger_mods</code></td><td>Which mods need to be down for activation. If both sides of a modifier are set (e.g. left ctrl and right ctrl) then only one is required to be pressed (e.g. left ctrl suffices). Use the <code>MOD_MASK_XXX</code> and <code>MOD_BIT()</code> macros for this.</td></tr><tr><td><code>layer_state_t layers</code></td><td>This is a BITMASK (!), defining which layers this override applies to. To use this override on layer i set the ith bit <code>(1 &lt;&lt; i)</code>.</td></tr><tr><td><code>uint8_t negative_mod_mask</code></td><td>Which modifiers cannot be down. It must hold that <code>(active_modifiers &amp; negative_mod_mask) == 0</code>, otherwise the key override will not be activated. An active override will be deactivated once this is no longer true.</td></tr><tr><td><code>uint8_t suppressed_mods</code></td><td>Modifiers to &#39;suppress&#39; while the override is active. To suppress a modifier means that even though the modifier key is held down, the host OS sees the modifier as not pressed. Can be used to suppress the trigger modifiers, as a trivial example.</td></tr><tr><td><code>uint16_t replacement</code></td><td>The complex keycode to send as replacement when this override is triggered. This can be a simple keycode, a key-modifier combination (e.g. <code>C(KC_A)</code>), or <code>KC_NO</code> (to register no replacement keycode). Use in combination with suppressed_mods to get the correct modifiers to be sent.</td></tr><tr><td><code>ko_option_t options</code></td><td>Options controlling the behavior of the override, such as what actions are allowed to activate the override.</td></tr><tr><td><code>bool (*custom_action)(bool activated, void *context)</code></td><td>If not NULL, this function will be called right before the replacement key is registered, along with the provided context and a flag indicating whether the override was activated or deactivated. This function allows you to run some custom actions for specific key overrides. If you return <code>false</code>, the replacement key is not registered/unregistered as it would normally. Return <code>true</code> to register and unregister the override normally.</td></tr><tr><td><code>void *context</code></td><td>A context that will be passed to the custom action function.</td></tr><tr><td><code>bool *enabled</code></td><td>If this points to false this override will not be used. Set to NULL to always have this override enabled.</td></tr></tbody></table><h2 id="reference-for-ko_option_t" tabindex="-1">Reference for <code>ko_option_t</code> <a class="header-anchor" href="#reference-for-ko_option_t" aria-label="Permalink to &quot;Reference for `ko_option_t` {#reference-for-ko_option_t}&quot;">​</a></h2><p>Bitfield with various options controlling the behavior of a key override.</p><table><thead><tr><th>Value</th><th>Description</th></tr></thead><tbody><tr><td><code>ko_option_activation_trigger_down</code></td><td>Allow activating when the trigger key is pressed down.</td></tr><tr><td><code>ko_option_activation_required_mod_down</code></td><td>Allow activating when a necessary modifier is pressed down.</td></tr><tr><td><code>ko_option_activation_negative_mod_up</code></td><td>Allow activating when a negative modifier is released.</td></tr><tr><td><code>ko_option_one_mod</code></td><td>If set, any of the modifiers in <code>trigger_mods</code> will be enough to activate the override (logical OR of modifiers). If not set, all the modifiers in <code>trigger_mods</code> have to be pressed (logical AND of modifiers).</td></tr><tr><td><code>ko_option_no_unregister_on_other_key_down</code></td><td>If set, the override will not deactivate when another key is pressed down. Use only if you really know you need this.</td></tr><tr><td><code>ko_option_no_reregister_trigger</code></td><td>If set, the trigger key will never be registered again after the override is deactivated.</td></tr><tr><td><code>ko_options_default</code></td><td>The default options used by the <code>ko_make_xxx</code> functions</td></tr></tbody></table><h2 id="for-advanced-users-inner-workings" tabindex="-1">For Advanced Users: Inner Workings <a class="header-anchor" href="#for-advanced-users-inner-workings" aria-label="Permalink to &quot;For Advanced Users: Inner Workings {#for-advanced-users-inner-workings}&quot;">​</a></h2><p>This section explains how a key override works in detail, explaining where each member of <code>key_override_t</code> comes into play. Understanding this is essential to be able to take full advantage of all the options offered by key overrides.</p><h4 id="activation" tabindex="-1">Activation <a class="header-anchor" href="#activation" aria-label="Permalink to &quot;Activation {#activation}&quot;">​</a></h4><p>When the necessary keys are pressed (<code>trigger_mods</code> + <code>trigger</code>), the override is &#39;activated&#39; and the replacement key is registered in the keyboard report (<code>replacement</code>), while the <code>trigger</code> key is removed from the keyboard report. The trigger modifiers may also be removed from the keyboard report upon activation of an override (<code>suppressed_mods</code>). The override will not activate if any of the <code>negative_modifiers</code> are pressed.</p><p>Overrides can activate in three different cases:</p><ol><li>The trigger key is pressed down and necessary modifiers are already down.</li><li>A necessary modifier is pressed down, while the trigger key and other necessary modifiers are already down.</li><li>A negative modifier is released, while all necessary modifiers and the trigger key are already down.</li></ol><p>Use the <code>option</code> member to customize which of these events are allowed to activate your overrides (default: all three).</p><p>In any case, a key override can only activate if the <code>trigger</code> key is the <em>last</em> non-modifier key that was pressed down. This emulates the behavior of how standard OSes (macOS, Windows, Linux) handle normal key input (to understand: Hold down <code>a</code>, then also hold down <code>b</code>, then hold down <code>shift</code>; <code>B</code> will be typed but not <code>A</code>).</p><h4 id="deactivation" tabindex="-1">Deactivation <a class="header-anchor" href="#deactivation" aria-label="Permalink to &quot;Deactivation {#deactivation}&quot;">​</a></h4><p>An override is &#39;deactivated&#39; when one of the trigger keys (<code>trigger_mods</code>, <code>trigger</code>) is lifted, another non-modifier key is pressed down, or one of the <code>negative_modifiers</code> is pressed down. When an override deactivates, the <code>replacement</code> key is removed from the keyboard report, while the <code>suppressed_mods</code> that are still held down are re-added to the keyboard report. By default, the <code>trigger</code> key is re-added to the keyboard report if it is still held down and no other non-modifier key has been pressed since. This again emulates the behavior of how standard OSes handle normal key input (To understand: hold down <code>a</code>, then also hold down <code>b</code>, then also <code>shift</code>, then release <code>b</code>; <code>A</code> will not be typed even though you are holding the <code>a</code> and <code>shift</code> keys). Use the <code>option</code> field <code>ko_option_no_reregister_trigger</code> to prevent re-registering the trigger key in all cases.</p><h4 id="key-repeat-delay" tabindex="-1">Key Repeat Delay <a class="header-anchor" href="#key-repeat-delay" aria-label="Permalink to &quot;Key Repeat Delay {#key-repeat-delay}&quot;">​</a></h4><p>A third way in which standard OS-handling of modifier-key input is emulated in key overrides is with a <a href="https://www.dummies.com/computers/pcs/set-your-keyboards-repeat-delay-and-repeat-rate/" target="_blank" rel="noreferrer">&#39;key repeat delay&#39;</a>. To explain what this is, let&#39;s look at how normal keyboard input is handled by mainstream OSes again: If you hold down <code>a</code>, followed by <code>shift</code>, you will see the letter <code>a</code> is first typed, then for a short moment nothing is typed and then repeating <code>A</code>s are typed. Take note that, although shift is pressed down just after <code>a</code> is pressed, it takes a moment until <code>A</code> is typed. This is caused by the aforementioned key repeat delay, and it is a feature that prevents unwanted repeated characters from being typed.</p><p>This applies equally to releasing a modifier: When you hold <code>shift</code>, then press <code>a</code>, the letter <code>A</code> is typed. Now if you release <code>shift</code> first, followed by <code>a</code> shortly after, you will not see the letter <code>a</code> being typed, even though for a short moment of time you were just holding down the key <code>a</code>. This is because no modified characters are typed until the key repeat delay has passed.</p><p>This exact behavior is implemented in key overrides as well: If a key override for <code>shift</code> + <code>a</code> = <code>b</code> exists, and <code>a</code> is pressed and held, followed by <code>shift</code>, you will not immediately see the letter <code>b</code> being typed. Instead, this event is deferred for a short moment, until the key repeat delay has passed, measured from the moment when the trigger key (<code>a</code>) was pressed down.</p><p>The duration of the key repeat delay is controlled with the <code>KEY_OVERRIDE_REPEAT_DELAY</code> macro. Define this value in your <code>config.h</code> file to change it. It is 500ms by default.</p><h2 id="difference-to-combos" tabindex="-1">Difference to Combos <a class="header-anchor" href="#difference-to-combos" aria-label="Permalink to &quot;Difference to Combos {#difference-to-combos}&quot;">​</a></h2><p>Note that key overrides are very different from <a href="./combo">combos</a>. Combos require that you press down several keys almost <em>at the same time</em> and can work with any combination of non-modifier keys. Key overrides work like keyboard shortcuts (e.g. <code>ctrl</code> + <code>z</code>): They take combinations of <em>multiple</em> modifiers and <em>one</em> non-modifier key to then perform some custom action. Key overrides are implemented with much care to behave just like normal keyboard shortcuts would in regards to the order of pressed keys, timing, and interaction with other pressed keys. There are a number of optional settings that can be used to really fine-tune the behavior of each key override as well. Using key overrides also does not delay key input for regular key presses, which inherently happens in combos and may be undesirable.</p><h2 id="neutralize-flashing-modifiers" tabindex="-1">Solution to the problem of flashing modifiers <a class="header-anchor" href="#neutralize-flashing-modifiers" aria-label="Permalink to &quot;Solution to the problem of flashing modifiers {#neutralize-flashing-modifiers}&quot;">​</a></h2><p>If the programs you use bind an action to taps of modifier keys (e.g. tapping left GUI to bring up the applications menu or tapping left Alt to focus the menu bar), you may find that using key overrides with suppressed mods falsely triggers those actions. To counteract this, you can define a <code>DUMMY_MOD_NEUTRALIZER_KEYCODE</code> in <code>config.h</code> that will get sent in between the register and unregister events of a suppressed modifier. That way, the programs on your computer will no longer interpret the mod suppression induced by key overrides as a lone tap of a modifier key and will thus not falsely trigger the undesired action.</p><p>Naturally, for this technique to be effective, you must choose a <code>DUMMY_MOD_NEUTRALIZER_KEYCODE</code> for which no keyboard shortcuts are bound to. Recommended values are: <code>KC_RIGHT_CTRL</code> or <code>KC_F18</code>. Please note that <code>DUMMY_MOD_NEUTRALIZER_KEYCODE</code> must be a basic, unmodified, HID keycode so values like <code>KC_NO</code>, <code>KC_TRANSPARENT</code> or <code>KC_PIPE</code> aka <code>S(KC_BACKSLASH)</code> are not permitted.</p><p>By default, only left Alt and left GUI are neutralized. If you want to change the list of applicable modifier masks, use the following in your <code>config.h</code>:</p><div class="language-c vp-adaptive-theme"><button title="Copy Code" class="copy"></button><span class="lang">c</span><pre class="shiki shiki-themes github-light github-dark vp-code"><code><span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">#define</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> MODS_TO_NEUTRALIZE</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> { </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">&lt;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">mod_mask_1</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">&gt;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, </span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">&lt;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">mod_mask_2</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">&gt;</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">, ... }</span></span></code></pre></div><p>Examples:</p><div class="language-c vp-adaptive-theme"><button title="Copy Code" class="copy"></button><span class="lang">c</span><pre class="shiki shiki-themes github-light github-dark vp-code"><code><span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">#define</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> DUMMY_MOD_NEUTRALIZER_KEYCODE</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> KC_RIGHT_CTRL</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// Neutralize left alt and left GUI (Default value)</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">#define</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> MODS_TO_NEUTRALIZE</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> { </span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_LEFT_ALT), </span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_LEFT_GUI) }</span></span>\n<span class="line"></span>\n<span class="line"><span style="--shiki-light:#6A737D;--shiki-dark:#6A737D;">// Neutralize left alt, left GUI, right GUI and left Control+Shift</span></span>\n<span class="line"><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">#define</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;"> MODS_TO_NEUTRALIZE</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;"> { </span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_LEFT_ALT), </span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_LEFT_GUI), </span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_RIGHT_GUI), </span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_LEFT_CTRL)</span><span style="--shiki-light:#D73A49;--shiki-dark:#F97583;">|</span><span style="--shiki-light:#6F42C1;--shiki-dark:#B392F0;">MOD_BIT</span><span style="--shiki-light:#24292E;--shiki-dark:#E1E4E8;">(KC_LEFT_SHIFT) }</span></span></code></pre></div><div class="warning custom-block"><p class="custom-block-title">WARNING</p><p>Do not use <code>MOD_xxx</code> constants like <code>MOD_LSFT</code> or <code>MOD_RALT</code>, since they&#39;re 5-bit packed bit-arrays while <code>MODS_TO_NEUTRALIZE</code> expects a list of 8-bit packed bit-arrays. Use <code>MOD_BIT(&lt;kc&gt;)</code> or <code>MOD_MASK_xxx</code> instead.</p></div>', 70);
const _hoisted_71 = [
  _hoisted_1
];
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", null, _hoisted_71);
}
const key_overrides = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render]]);
export {
  __pageData,
  key_overrides as default
};
